@@ -20,7 +20,7 @@ our $VERSION;
 our $DEBUG;
 
 BEGIN {
-  our $VERSION = qv(8.1.5);
+  our $VERSION = qv(8.1.6);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -251,7 +251,7 @@ sub filter {
       $t .= "],},];";
     }
 
-    $prefix .= " ($_)" if $DEBUG eq "verify"; # keep untyped sigs for perl verification
+     $prefix .= " ($_,\@_dummy)" if $DEBUG eq "verify"; # keep untyped sigs for perl verification
     warn "$prefix { CHECK{ $t } $suffix";
     "$prefix { no warnings qw/experimental shadow/; CHECK{ $t } $suffix";
   )gmsex if $status > 0;
